@@ -4,7 +4,7 @@
 """
    TODO Purpose of the file
    @project: hspylib
-   @package: hspylib.main.hspylib.addons.appman
+   @package: hspylib.hspylib.addons.appman
       @file: appman_enums.py
    @created: Fri, 29 Jul 2022
     @author: "<B>H</B>ugo <B>S</B>aporetti <B>J</B>unior")"
