@@ -83,7 +83,7 @@ def log_init(
 
     log.basicConfig(level=level, handlers=handlers)
 
-    return (os.path.exists(filename or '') and file_enable) or console_enable
+    return file_enable if os.path.exists(filename or '') else console_enable
 
 
 def is_debugging() -> bool:
@@ -162,8 +162,7 @@ def safe_del_file(filename: str, on_not_found_except: bool = False) -> bool:
     else:
         if on_not_found_except:
             raise FileNotFoundError(f'File was not found on the system: {filename}')
-        else:
-            return False
+        return False
 
     return True
 
@@ -175,7 +174,7 @@ def file_is_not_empty(filename: str) -> bool:
     return os.path.exists(filename) and os.stat(filename).st_size > 0
 
 
-def touch_file(filename: str, encoding: str = Charset.UTF_8.value) -> None:
+def touch_file(filename: str, encoding: str = Charset.UTF_8.val) -> None:
     """Change file modification time
     :param filename: the name of the file to be modified
     :param encoding: the file encoding
